.. _lmlib_api_utils:

Utils
=====


**Package Abstract ::** This package is a collection of utility functions accelerate algorithm development and/or for educative purposes:

- deterministic and stochastic signals generators
- a collection of recorded biological signals, see :ref:`lmlib_signal_catalog`
- experimental functions (beta)


.. autosummary::
   :toctree: _autosummary
   :template: module

   lmlib.utils.generator
   lmlib.utils.beta



















